==> react-form-mobx-0.2.1.tgz: package/es/Demon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp, _initialiseProps;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Children } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import { isFunction, isEmpty, warn } from './utils';
import { FormatTypesKeys } from './FormatTypes';
import Context from './Context';
import withFormStore from './withFormStore';

var Demon = (_dec = withFormStore(), _dec(_class = observer(_class = (_temp = _class2 = function (_Component) {
	_inherits(Demon, _Component);

	function Demon(props) {
		_classCallCheck(this, Demon);

		var _this = _possibleConstructorReturn(this, (Demon.__proto__ || Object.getPrototypeOf(Demon)).call(this, props));

		_initialiseProps.call(_this);

		var forwardedProps = props.forwardedProps,
		    formStore = props.formStore,
		    isObject = props.isObject,
		    isArray = props.isArray,
		    checkable = props.checkable,
		    isRadio = props.isRadio,
		    propOnChange = props.propOnChange;

		var name = forwardedProps.name,
		    otherForwardedProps = _objectWithoutProperties(forwardedProps, ['name']);

		var options = _extends({
			isObject: isObject,
			isArray: isArray,
			checkable: checkable,
			isRadio: isRadio
		}, otherForwardedProps);

		if (checkable && isEmpty(forwardedProps.value)) {
			options.value = true;
			if (!forwardedProps.format) options.format = 'boolean';
		}

		if (isObject) {
			options.onChange = otherForwardedProps[propOnChange];
		}

		_this.inputStore = formStore.attach(name, options);
		_this.inputStore.validate();
		return _this;
	}

	_createClass(Demon, [{
		key: 'componentWillUnmount',
		value: function componentWillUnmount() {
			this.props.formStore.detach(this.inputStore.key);
		}
	}, {
		key: 'renderChildren',
		value: function renderChildren() {
			var _extends2;

			var inputStore = this.inputStore,
			    _inputStore = this.inputStore,
			    value = _inputStore.value,
			    isChecked = _inputStore.isChecked,
			    _props = this.props,
			    _props$forwardedProps = _props.forwardedProps,
			    defaultValue = _props$forwardedProps.defaultValue,
			    defaultChecked = _props$forwardedProps.defaultChecked,
			    name = _props$forwardedProps.name,
			    validation = _props$forwardedProps.validation,
			    inputFilter = _props$forwardedProps.inputFilter,
			    outputFilter = _props$forwardedProps.outputFilter,
			    format = _props$forwardedProps.format,
			    enforceSubmit = _props$forwardedProps.enforceSubmit,
			    enumeration = _props$forwardedProps.enum,
			    pattern = _props$forwardedProps.pattern,
			    maxLength = _props$forwardedProps.maxLength,
			    minLength = _props$forwardedProps.minLength,
			    maximum = _props$forwardedProps.maximum,
			    exclusiveMaximum = _props$forwardedProps.exclusiveMaximum,
			    minimum = _props$forwardedProps.minimum,
			    exclusiveMinimum = _props$forwardedProps.exclusiveMinimum,
			    forwardedProps = _objectWithoutProperties(_props$forwardedProps, ['defaultValue', 'defaultChecked', 'name', 'validation', 'inputFilter', 'outputFilter', 'format', 'enforceSubmit', 'enum', 'pattern', 'maxLength', 'minLength', 'maximum', 'exclusiveMaximum', 'minimum', 'exclusiveMinimum']),
			    propOnChange = _props.propOnChange,
			    propOnKeyPress = _props.propOnKeyPress,
			    propOnBlur = _props.propOnBlur,
			    checkable = _props.checkable,
			    children = _props.children;

			var props = _extends({
				value: value
			}, forwardedProps, (_extends2 = {}, _defineProperty(_extends2, propOnChange, this.handleChange), _defineProperty(_extends2, propOnKeyPress, this.handleKeyPress), _defineProperty(_extends2, propOnBlur, this.handleBlur), _extends2));
			var validState = inputStore.getValidState();
			if (checkable && !props.hasOwnProperty('checked')) {
				props.checked = isChecked;
			}
			return Children.only(children(props, validState));
		}
	}, {
		key: 'render',
		value: function render() {
			var inputStore = this.inputStore,
			    _props2 = this.props,
			    children = _props2.children,
			    isObject = _props2.isObject;

			return isObject ? React.createElement(
				Context.Provider,
				{ value: inputStore },
				children()
			) : this.renderChildren();
		}
	}]);

	return Demon;
}(Component), _class2.propTypes = {
	children: PropTypes.func.isRequired,
	formStore: PropTypes.object.isRequired,
	forwardedProps: PropTypes.shape({
		name: PropTypes.string.isRequired,
		value: PropTypes.any,
		defaultValue: PropTypes.any,
		validation: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.func), PropTypes.func]),
		required: PropTypes.bool,
		inputFilter: PropTypes.func,
		outputFilter: PropTypes.func,
		format: PropTypes.oneOf(FormatTypesKeys),
		enforceSubmit: PropTypes.bool,

		enum: PropTypes.array,
		pattern: PropTypes.instanceOf(RegExp),
		maxLength: PropTypes.number,
		minLength: PropTypes.number,
		maximum: PropTypes.number,
		exclusiveMaximum: PropTypes.number,
		minimum: PropTypes.number,
		exclusiveMinimum: PropTypes.number
	}).isRequired,

	checkable: PropTypes.bool,
	isRadio: PropTypes.bool,

	getValueFromChangeEvent: PropTypes.func,
	getCheckedFromChangeEvent: PropTypes.func,
	getKeyFromKeyPressEvent: PropTypes.func,
	propOnChange: PropTypes.string,
	propOnKeyPress: PropTypes.string,
	propOnBlur: PropTypes.string,

	isObject: PropTypes.bool,
	isArray: PropTypes.bool
}, _class2.defaultProps = {
	forwardedProps: {},
	checkable: false,
	isRadio: false,
	getValueFromChangeEvent: function getValueFromChangeEvent(ev) {
		return ev.currentTarget.value;
	},
	getCheckedFromChangeEvent: function getCheckedFromChangeEvent(ev) {
		return ev.currentTarget.checked;
	},
	getKeyFromKeyPressEvent: function getKeyFromKeyPressEvent(ev) {
		return ev.key;
	},
	propOnChange: 'onChange',
	propOnKeyPress: 'onKeyPress',
	propOnBlur: 'onBlur',
	isObject: false,
	isArray: false
}, _initialiseProps = function _initialiseProps() {
	var _this2 = this;

	this.handleChange = function () {
		var _props3 = _this2.props,
		    forwardedProps = _props3.forwardedProps,
		    checkable = _props3.checkable,
		    getValueFromChangeEvent = _props3.getValueFromChangeEvent,
		    getCheckedFromChangeEvent = _props3.getCheckedFromChangeEvent,
		    propOnChange = _props3.propOnChange;

		var onChange = forwardedProps[propOnChange];
		if (isFunction(onChange)) onChange.apply(undefined, arguments);

		if (checkable) {
			try {
				var checked = getCheckedFromChangeEvent.apply(undefined, arguments);
				_this2.inputStore.isChecked = checked;
			} catch (err) {
				warn('Failed to get checked from "' + propOnChange + '",', 'changing "props.getCheckedFromChangeEvent" may resolve this problem.');
				console.error(err);
			}
		} else {
			try {
				var value = getValueFromChangeEvent.apply(undefined, arguments);
				_this2.inputStore.value = value;
			} catch (err) {
				warn('Failed to get value from "' + propOnChange + '",', 'changing "props.getValueFromChangeEvent" may resolve this problem.');
				console.error(err);
			}
		}

		_this2.inputStore.clearAndValidate();
		_this2.inputStore.touch();

		var parentStore = _this2.inputStore.parentStore;

		parentStore.change(_this2.inputStore);
	};

	this.handleKeyPress = function () {
		var _props4 = _this2.props,
		    forwardedProps = _props4.forwardedProps,
		    formStore = _props4.formStore,
		    propOnKeyPress = _props4.propOnKeyPress,
		    getKeyFromKeyPressEvent = _props4.getKeyFromKeyPressEvent;

		var onKeyPress = forwardedProps[propOnKeyPress];
		if (isFunction(onKeyPress)) onKeyPress.apply(undefined, arguments);
		var key = void 0;
		try {
			key = getKeyFromKeyPressEvent.apply(undefined, arguments);
		} catch (err) {
			warn('Failed to get key from "' + propOnKeyPress + '",', 'changing "props.getKeyFromKeyPressEvent" may resolve this problem.');
			console.error(err);
		}
		if (key === 'Enter') formStore.submit();
	};

	this.handleBlur = function () {
		var _props5 = _this2.props,
		    forwardedProps = _props5.forwardedProps,
		    propOnBlur = _props5.propOnBlur;

		var onBlur = forwardedProps[propOnBlur];
		if (isFunction(onBlur)) onBlur.apply(undefined, arguments);
		_this2.inputStore.touch();
	};
}, _temp)) || _class) || _class);
export { Demon as default };

==> react-form-mobx-0.4.0.tgz: package/es/Demon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp, _initialiseProps;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Children } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import { isFunction, isEmpty, warn } from './utils';
import { FormatTypesKeys } from './FormatTypes';
import Context from './Context';
import withFormStore from './withFormStore';

var Demon = (_dec = withFormStore(), _dec(_class = observer(_class = (_temp = _class2 = function (_Component) {
	_inherits(Demon, _Component);

	function Demon(props) {
		_classCallCheck(this, Demon);

		var _this = _possibleConstructorReturn(this, (Demon.__proto__ || Object.getPrototypeOf(Demon)).call(this, props));

		_initialiseProps.call(_this);

		var forwardedProps = props.forwardedProps,
		    formStore = props.formStore,
		    isObject = props.isObject,
		    isArray = props.isArray,
		    checkable = props.checkable,
		    isRadio = props.isRadio,
		    propOnChange = props.propOnChange;

		var name = forwardedProps.name,
		    otherForwardedProps = _objectWithoutProperties(forwardedProps, ['name']);

		var options = _extends({
			isObject: isObject,
			isArray: isArray,
			checkable: checkable,
			isRadio: isRadio
		}, otherForwardedProps);

		if (checkable && isEmpty(forwardedProps.value)) {
			options.value = true;
			if (!forwardedProps.format) options.format = 'boolean';
		}

		if (isObject) {
			options.onChange = otherForwardedProps[propOnChange];
		}

		_this.inputStore = formStore.attach(name, options);
		_this.inputStore.validate();
		return _this;
	}

	_createClass(Demon, [{
		key: 'componentWillUnmount',
		value: function componentWillUnmount() {
			this.props.formStore.detach(this.inputStore.key);
		}
	}, {
		key: 'renderChildren',
		value: function renderChildren() {
			var _extends2;

			var inputStore = this.inputStore,
			    _inputStore = this.inputStore,
			    value = _inputStore.value,
			    isChecked = _inputStore.isChecked,
			    _props = this.props,
			    _props$forwardedProps = _props.forwardedProps,
			    defaultValue = _props$forwardedProps.defaultValue,
			    defaultChecked = _props$forwardedProps.defaultChecked,
			    name = _props$forwardedProps.name,
			    preValidate = _props$forwardedProps.preValidate,
			    validation = _props$forwardedProps.validation,
			    inputFilter = _props$forwardedProps.inputFilter,
			    outputFilter = _props$forwardedProps.outputFilter,
			    preFormat = _props$forwardedProps.preFormat,
			    format = _props$forwardedProps.format,
			    formatFunc = _props$forwardedProps.formatFunc,
			    enforceSubmit = _props$forwardedProps.enforceSubmit,
			    enumeration = _props$forwardedProps.enum,
			    pattern = _props$forwardedProps.pattern,
			    maxLength = _props$forwardedProps.maxLength,
			    minLength = _props$forwardedProps.minLength,
			    maximum = _props$forwardedProps.maximum,
			    exclusiveMaximum = _props$forwardedProps.exclusiveMaximum,
			    minimum = _props$forwardedProps.minimum,
			    exclusiveMinimum = _props$forwardedProps.exclusiveMinimum,
			    forwardedProps = _objectWithoutProperties(_props$forwardedProps, ['defaultValue', 'defaultChecked', 'name', 'preValidate', 'validation', 'inputFilter', 'outputFilter', 'preFormat', 'format', 'formatFunc', 'enforceSubmit', 'enum', 'pattern', 'maxLength', 'minLength', 'maximum', 'exclusiveMaximum', 'minimum', 'exclusiveMinimum']),
			    propOnChange = _props.propOnChange,
			    propOnKeyPress = _props.propOnKeyPress,
			    propOnBlur = _props.propOnBlur,
			    checkable = _props.checkable,
			    children = _props.children;

			var props = _extends({
				value: value
			}, forwardedProps, (_extends2 = {}, _defineProperty(_extends2, propOnChange, this.handleChange), _defineProperty(_extends2, propOnKeyPress, this.handleKeyPress), _defineProperty(_extends2, propOnBlur, this.handleBlur), _extends2));
			var validState = inputStore.getValidState();
			if (checkable && !props.hasOwnProperty('checked')) {
				props.checked = isChecked;
			}
			return Children.only(children(props, validState));
		}
	}, {
		key: 'render',
		value: function render() {
			var inputStore = this.inputStore,
			    _props2 = this.props,
			    children = _props2.children,
			    isObject = _props2.isObject;

			return isObject ? React.createElement(
				Context.Provider,
				{ value: inputStore },
				children()
			) : this.renderChildren();
		}
	}]);

	return Demon;
}(Component), _class2.propTypes = {
	children: PropTypes.func.isRequired,
	formStore: PropTypes.object.isRequired,
	forwardedProps: PropTypes.shape({
		name: PropTypes.string.isRequired,
		value: PropTypes.any,
		defaultValue: PropTypes.any,
		preValidate: PropTypes.func,
		validation: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.func), PropTypes.func]),
		required: PropTypes.bool,
		inputFilter: PropTypes.func,
		outputFilter: PropTypes.func,
		preFormat: PropTypes.func,
		format: PropTypes.oneOf(FormatTypesKeys),
		formatFunc: PropTypes.func,
		enforceSubmit: PropTypes.bool,

		enum: PropTypes.array,
		pattern: PropTypes.instanceOf(RegExp),
		maxLength: PropTypes.number,
		minLength: PropTypes.number,
		maximum: PropTypes.number,
		exclusiveMaximum: PropTypes.number,
		minimum: PropTypes.number,
		exclusiveMinimum: PropTypes.number
	}).isRequired,

	checkable: PropTypes.bool,
	isRadio: PropTypes.bool,

	getValueFromChangeEvent: PropTypes.func,
	getCheckedFromChangeEvent: PropTypes.func,
	getKeyFromKeyPressEvent: PropTypes.func,
	propOnChange: PropTypes.string,
	propOnKeyPress: PropTypes.string,
	propOnBlur: PropTypes.string,

	isObject: PropTypes.bool,
	isArray: PropTypes.bool
}, _class2.defaultProps = {
	forwardedProps: {},
	checkable: false,
	isRadio: false,
	getValueFromChangeEvent: function getValueFromChangeEvent(ev) {
		return ev.currentTarget.value;
	},
	getCheckedFromChangeEvent: function getCheckedFromChangeEvent(ev) {
		return ev.currentTarget.checked;
	},
	getKeyFromKeyPressEvent: function getKeyFromKeyPressEvent(ev) {
		return ev.key;
	},
	propOnChange: 'onChange',
	propOnKeyPress: 'onKeyPress',
	propOnBlur: 'onBlur',
	isObject: false,
	isArray: false
}, _initialiseProps = function _initialiseProps() {
	var _this2 = this;

	this.handleChange = function () {
		var _props3 = _this2.props,
		    forwardedProps = _props3.forwardedProps,
		    checkable = _props3.checkable,
		    getValueFromChangeEvent = _props3.getValueFromChangeEvent,
		    getCheckedFromChangeEvent = _props3.getCheckedFromChangeEvent,
		    propOnChange = _props3.propOnChange;

		var onChange = forwardedProps[propOnChange];
		if (isFunction(onChange)) onChange.apply(undefined, arguments);

		if (checkable) {
			try {
				var checked = getCheckedFromChangeEvent.apply(undefined, arguments);
				_this2.inputStore.isChecked = checked;
			} catch (err) {
				warn('Failed to get checked from "' + propOnChange + '",', 'changing "props.getCheckedFromChangeEvent" may resolve this problem.');
				console.error(err);
			}
		} else {
			try {
				var value = getValueFromChangeEvent.apply(undefined, arguments);
				_this2.inputStore.value = value;
			} catch (err) {
				warn('Failed to get value from "' + propOnChange + '",', 'changing "props.getValueFromChangeEvent" may resolve this problem.');
				console.error(err);
			}
		}

		_this2.inputStore.clearAndValidate();
		_this2.inputStore.touch();

		var parentStore = _this2.inputStore.parentStore;

		parentStore.change(_this2.inputStore);
	};

	this.handleKeyPress = function () {
		var _props4 = _this2.props,
		    forwardedProps = _props4.forwardedProps,
		    formStore = _props4.formStore,
		    propOnKeyPress = _props4.propOnKeyPress,
		    getKeyFromKeyPressEvent = _props4.getKeyFromKeyPressEvent;

		var onKeyPress = forwardedProps[propOnKeyPress];
		if (isFunction(onKeyPress)) onKeyPress.apply(undefined, arguments);
		var key = void 0;
		try {
			key = getKeyFromKeyPressEvent.apply(undefined, arguments);
		} catch (err) {
			warn('Failed to get key from "' + propOnKeyPress + '",', 'changing "props.getKeyFromKeyPressEvent" may resolve this problem.');
			console.error(err);
		}
		if (key === 'Enter') formStore.submit();
	};

	this.handleBlur = function () {
		var _props5 = _this2.props,
		    forwardedProps = _props5.forwardedProps,
		    propOnBlur = _props5.propOnBlur;

		var onBlur = forwardedProps[propOnBlur];
		if (isFunction(onBlur)) onBlur.apply(undefined, arguments);
		_this2.inputStore.touch();
	};
}, _temp)) || _class) || _class);
export { Demon as default };
